@@ -5,9 +5,6 @@
 import pytest
 
 
-from pyargcbr import pyargcbr
-
-
 @pytest.fixture
 def response():
     """Sample pytest fixture.
@@ -22,3 +19,4 @@ def test_content(response):
     """Sample pytest test function with the pytest fixture as an argument."""
     # from bs4 import BeautifulSoup
     # assert 'GitHub' in BeautifulSoup(response.content).title.string
+    assert True
